-- Modified by Alix Krahn
-- January 20, 2014
-- Original file from Nancy Minderman
-- Created December 17, 2013
-- Makes much use of the Altera "Insert Template" feature
-- nancy.minderman@ualberta.ca
-- Modified January 13, 2014 to use the DE2_CONSTANTS package

-- A library clause declares a name as a library.  It 
-- does not create the library; it simply forward declares 
-- it. 
library ieee;

-- Use clauses import declarations into the current scope.	
-- If more than one use clause imports the same name into the
-- the same scope, none of the names are imported.


-- Commonly imported packages:

-- STD_LOGIC and STD_LOGIC_VECTOR types, and relevant functions
use ieee.std_logic_1164.all;

-- SIGNED and UNSIGNED types, and relevant functions
use ieee.numeric_std.all;

-- Basic sequential functions and concurrent procedures
use ieee.VITAL_Primitives.all;

use work.DE2_CONSTANTS.all;

entity Frequency_Counter is

	port
	(
		-- clock interface
		clk		:	in std_logic;
		
		-- reset interface
		reset_n		:	in std_logic;
		
		-- USB external signals
		USB_ADDR		:	out std_logic_vector(1 downto 0);
		USB_CS_N		:	out std_logic := '1';
		USB_RD_N		: 	out std_logic := '1';
		USB_WR_N		:	out std_logic := '1';
		USB_RST_N	:	out std_logic := '1';
		USB_DATA		:	inout	std_logic_vector(15 downto 0);
		
		USB_INT0		:	in std_logic;
		
		-- memory mapped slave interface
		avs_s0_interrupt	:	out std_logic;
		avs_s0_address		: 	in std_logic_vector(1 downto 0);
		avs_s0_read_n		:	in std_logic;
		avs_s0_readdata	:	out std_logic_vector(15 downto 0);
		avs_s0_write_n		:	in std_logic;
		avs_s0_writedata	: 	in std_logic_vector(15 downto 0)
	);
end Frequency_Counter;


architecture avalon of Frequency_Counter is

	signal buf : std_logic_vector(15 downto 0);
	
	begin
	avs_s0_interrupt <= USB_INT0;
	USB_ADDR <= avs_s0_address;
	USB_DATA <= avs_s0_writedata when avs_s0_write_n = '0' else (others => 'Z');
	avs_s0_readdata <= USB_DATA when avs_s0_read_n = '0' else (others => 'Z');
	USB_RD_N <= avs_s0_read_n;
	USB_WR_N <= avs_s0_write_n;
	USB_RST_N <= reset_n;
	pCS: process (avs_s0_read_n, avs_s0_write_n) is
	begin
		if avs_s0_read_n = '0' or avs_s0_write_n = '0' then
			USB_CS_N <= '0';
		else
			USB_CS_N <= '1';
		end if;
	end process pCS;
end architecture avalon;